####Setup####

library(dplyr)
library(magrittr)
library(ggplot2)
library(readxl)
library(tidyr)

####DPP3 model estimates####

#Read in data

Data <- read.csv("Inputs/DataWithOutliers.csv", header = TRUE, stringsAsFactors = FALSE)

#Re-run the DPP3 models

ModelN <- Data %>% filter(N1outlier == 0) %>% lm(network ~ lines + icp, data = .)

ModelNN <- Data %>% filter(NN1outlier == 0 & year < 2019) %>% lm(nonnetwork ~ lines + icp, data = .)

####Processing DPP4 data####

#Read in the new data
#Read in the inflation index

DataNew <- read.csv("Inputs/DPP4 - Opex data - v0.2.csv", header = TRUE, stringsAsFactors = FALSE)
InflationIndex <- read.csv("Inputs/InflationIndex.csv", header = TRUE, stringsAsFactors = FALSE)

#Adjust for operating lease adjustments
#Assuming these are nominal

OpLease <- read_xlsx("Inputs/Operating-lease-model-EDB-DPP3-final-determination-27-November-2019.xlsx", sheet = "Output (opex proj)", skip = 5)
OpLease <- filter(OpLease, !is.na(Name))
colnames(OpLease)[2:3] <- c("Year","Type")
OpLease <- filter(OpLease, !is.na(Year))
OpLease <- mutate(OpLease, Name = ifelse(grepl("Non-network", Name, fixed = TRUE),"nonnetworkAdj","networkAdj"))
OpLease <- dplyr::select(OpLease, 1:2,4:20)
OpLease <- pivot_longer(OpLease,3:19)
OpLease <- OpLease %>% group_by(Name,Year,name) %>% summarise(Value = sum(value))
OpLease_nonNetwork <- filter(OpLease, Name == "nonnetworkAdj") %>% ungroup %>% dplyr::select(year = Year, edb = name, nonnetworkAdj = Value)
OpLease_Network <- filter(OpLease, Name == "networkAdj")  %>% ungroup %>% dplyr::select(year = Year, edb = name, networkAdj = Value)

DataNew <- left_join(DataNew, OpLease_nonNetwork, by = c("edb","year"))
DataNew <- left_join(DataNew, OpLease_Network, by = c("edb","year"))

DataNew[is.na(DataNew)] <- 0

DataNew <- DataNew %>% mutate(nonnetwork = nonnetwork + nonnetworkAdj, network = network + networkAdj)

#Index the data to 2019 real

DataNew <- left_join(DataNew, InflationIndex, by = 'year')

DataNew <- mutate(DataNew, network = network / Index)
DataNew <- mutate(DataNew, nonnetwork = nonnetwork / Index)

DataNew$lines <- as.numeric(DataNew$lines)

#Take logs

vars <- c("ICP", "lines", "network", "nonnetwork")
for (var in vars) {
  DataNew[[paste0("Log_",var)]] <- log(DataNew[[var]])
}

####Network####

#Clean data

DataForPredictionN <- DataNew

DataForPredictionN <- dplyr::select(DataNew, Log_lines, Log_ICP)
DataForPredictionN <- rename(DataForPredictionN, "icp" = Log_ICP, "lines" = Log_lines)

DataForPredictionN$PredictionN <- predict(ModelN, DataForPredictionN)

DataNew$Log_PredictionN <- DataForPredictionN$PredictionN 

DataNew$PredictionNetwork <- exp(DataNew$Log_PredictionN)

#Calculate mean square error

DataNew <- DataNew %>% mutate(Error = Log_network - Log_PredictionN, SqrError = Error^2, AbsError = abs(Error))

MeanSqr <- DataNew %>% group_by(year) %>% summarise(MSE = mean(SqrError, na.rm = TRUE))

#Calculate mean absolute error

MeanAbs <- DataNew %>% group_by(year) %>% summarise(MAE = mean(AbsError, na.rm = TRUE), MeanError = mean(Error, na.rm = TRUE))

#Plots
#Predicted versus actual, 

DataNew <- DataNew %>% mutate(NewData =  ifelse(year <= 2019,0,1))

ggplot(DataNew, aes(x = Log_PredictionN, y = Log_network, color = as.factor(NewData))) + geom_point() + geom_abline(slope = 1, intercept = 0)

#Residuals versus fitted

DataNew <- DataNew %>% mutate(resid = Log_network - Log_PredictionN)

ggplot(DataNew, aes(x = Log_PredictionN, y = resid, color = as.factor(NewData))) + geom_point()

DataNew %>% filter(NewData == 1) %>% ggplot(aes(x = Log_PredictionN, y = resid, color = as.factor(NewData))) + geom_point() 

ggplot(DataNew, aes(x = Log_PredictionN, y = resid, color = as.factor(edb), label = edb)) + geom_point() 

####Non-Network####

DataForPredictionNN <- DataNew

DataForPredictionNN <- dplyr::select(DataNew, Log_lines, Log_ICP)
DataForPredictionNN <- rename(DataForPredictionNN, "icp" = Log_ICP, "lines" = Log_lines)

DataForPredictionNN$PredictionNN <- predict(ModelNN, DataForPredictionNN)

DataNew$Log_PredictionNN <- DataForPredictionNN$PredictionNN 

DataNew$PredictionNonNetwork <- exp(DataNew$Log_PredictionN)

#Calculate mean square error

DataNew <- DataNew %>% mutate(ErrorNN = Log_nonnetwork - Log_PredictionNN, SqrErrorNN = ErrorNN^2, AbsErrorNN = abs(ErrorNN))

MeanSqr <- DataNew %>% group_by(year) %>% summarise(MSE = mean(SqrErrorNN, na.rm = TRUE))

#Calculate mean absolute error

MeanAbs <- DataNew %>% group_by(year) %>% summarise(MAE = mean(AbsErrorNN, na.rm = TRUE), MeanError = mean(ErrorNN, na.rm = TRUE))

#Predicted versus actual, 

ggplot(DataNew, aes(x = Log_PredictionNN, y = Log_nonnetwork, color = as.factor(NewData))) + geom_point() + geom_abline(slope = 1, intercept = 0)

#Residuals versus fitted

DataNew <- DataNew %>% mutate(resid = Log_nonnetwork - Log_PredictionNN)

ggplot(DataNew, aes(x = Log_PredictionN, y = resid, color = as.factor(NewData))) + geom_point()



